#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const commander_1 = require("commander");
const commands_1 = require("./commands");
const utils_1 = require("./utils");
const logger_1 = require("./logger");
main().catch(error => {
    logger_1.logger.error(`Encountered an unexpected error: ${error}`);
});
async function main() {
    commander_1.program
        .name('cms-mrf-validator')
        .description('Tool for validating health coverage machine-readable files.')
        .option('-d, --debug', 'show debug output')
        .hook('preAction', thisCommand => {
        if (thisCommand.opts().debug) {
            logger_1.logger.level = 'debug';
            logger_1.logger.debug(process.argv.join(' '));
        }
    })
        .command('validate')
        .description('Validate a file against a specific published version of a CMS schema.')
        .usage('<data-file> [options]')
        .argument('<data-file>', 'path to data file to validate')
        .option('--schema-version <version>', 'version of schema to use for validation')
        .option('-o, --out <out>', 'output path')
        .addOption(new commander_1.Option('-t, --target <schema>', 'name of schema to use')
        .choices(utils_1.config.AVAILABLE_SCHEMAS)
        .default('in-network-rates'))
        .option('-s, --strict', 'enable strict checking, which prohibits additional properties in data file')
        .option('-y, --yes-all', 'automatically respond "yes" to confirmation prompts')
        .action(commands_1.validate);
    commander_1.program
        .command('from-url')
        .description('Validate the file retrieved from a URL against a specific published version of a CMS schema.')
        .usage('<data-url> [options]')
        .argument('<data-url>', 'URL to data file to validate')
        .option('--schema-version <version>', 'version of schema to use for validation')
        .option('-o, --out <out>', 'output path')
        .addOption(new commander_1.Option('-t, --target <schema>', 'name of schema to use')
        .choices(utils_1.config.AVAILABLE_SCHEMAS)
        .default('in-network-rates'))
        .option('-s, --strict', 'enable strict checking, which prohibits additional properties in data file')
        .option('-y, --yes-all', 'automatically respond "yes" to confirmation prompts')
        .action((dataUrl, options) => {
        (0, commands_1.validateFromUrl)(dataUrl, options).then(result => {
            if (result) {
                process.exitCode = 0;
            }
            else {
                process.exitCode = 1;
            }
        });
    });
    commander_1.program
        .command('update')
        .description('Update the available schemas from the CMS repository.')
        .action(commands_1.update);
    commander_1.program.parseAsync(process.argv);
}
